subject

# XMLRésuméLibrary: User Guide

street2 | Element Reference | subjects

## Name

subject — A name of a class or topic of study

## Synopsis

### Content Model

    (title,result)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `subject` element contains the `title` of a class or other course of study, as well as its `result`.

A subject's title can be as general as “mathematics” (a general field of study), or as specific as “ECEn 224 Electrostatics Fall 1994” (a specific university class, along with the date the class was taken).

### Parents

`subject` may be contained in these elements: `subjects`

## Examples

    <subject>
      <title>English</title>
      <result>A-</result>
    </subject>

    <subject>
      <title>PE 194 Crabwalking</title>
      <result>F</result>
    </subject>

street2 | Element Reference | subjects